//Получение cell-массива из csv
function [cellNames]=CellNamesFromStrCSV(strCSVNames,..//Строки имен в формате .csv
                                         csvSeparator,..//Разделитель .csv
                                         toIndexes..//Необходимость перевода в индексы
                                         )
    //Проверяем аргументы
    select argn(2)
    case 0 then
        strCSVNames = [];//Строки имен в формате .csv
        csvSeparator = ',';//Разделитель .csv по умолчанию запятая
        toIndexes = %t;//По умолчанию переводим в индексы
    case 1 then
        csvSeparator = ',';//Разделитель .csv по умолчанию запятая
        toIndexes = %t;//По умолчанию переводим в индексы
    case 2 then
        if type(csvSeparator) == 4 then
            toIndexes = csvSeparator;
            csvSeparator = ',';//Разделитель .csv по умолчанию запятая
        else
            toIndexes = %t;//По умолчанию переводим в индексы
        end
    end
    
    //Обрабатываем случай пустой строки имен
    if isempty(strCSVNames) then
        cellNames = [];
        
        return;
    end
    
    //Проверяем корректность аргументов
    if type(strCSVNames) ~= 10 then
        error('The argument strCSVNames of function CellNamesFromStrCSV must be matrix 1xM of strings');
    end
    if and(length(strCSVNames) == 0) then
        cellNames = [];
        
        return;
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') > 1) then
        error('The argument strCSVNames of function CellNamesFromStrCSV must be string scalar');
    end
    if type(toIndexes) ~= 4 then
        error('The argument toIndexes of function CellNamesFromStrCSV must be matrix 1xM of boolean');
    end
    strCSVNames = matrix(strCSVNames,1,-1);//Приводим строки имен в формате .csv к матрице-строке
    toIndexes = matrix(toIndexes,1,-1);//Приводим необходимости получения индексов данных в виде индексов к матрице-строке
    nStrCSVNames = size(strCSVNames,'*');//Число строк имен в составе csv
    nToIndexes = size(toIndexes,'*');//Число необходимостей парсинга индексов имен
    if nToIndexes < nStrCSVNames then
        toIndexes = [toIndexes,repmat(toIndexes($),[1,nStrCSVNames - nToIndexes])];
    end
    
    //Формируем cell-массив имен
    cellNames = cell(1,nStrCSVNames);//Создаем cell-массив
    for ind=1:nStrCSVNames
        //Парсим строку
        cellNames{ind} = ReadNamesFromCSV(strCSVNames(ind),csvSeparator);
        
        //Проверяем пустоту имен
        if length(cellNames{ind}) == 0 then
            cellNames{ind} = [];
            
            continue;
        end
        
        //При необходимости переводим строки в массив целочисленных индексов
        if toIndexes then
            //Проверяем, являются ли элементы числами
            isInt = [];
            for el=matrix(cellNames{ind},1,-1)
                isInt = [isInt,isdigit(el)];
            end
            isInt = and(isInt);
            
            //Парсим в индексы
            if isInt then
                cellNames{ind} = evstr(cellNames{ind});
            end
        end
    end
endfunction
