//Генерация случайных чисел на поддиапазонах с равномерным законом распределения
function [Functions,..//Функции
          argumentsNames,..//Имена (индексы) аргументов
          rezultsNames,..//Имена результатов
          isVectorized..//Функция векторизована или нет
          ]=CountFunctionsParse(CountFunctionsFilesNames,..//Имя файла аттрибутов равномерно распределенных случайных величин
                                csvSeparator,..//.csv-разделитель
                                toIndexes..//Надо ли переводить в индексы
                                )
    //Проверяем агрументы
    [nRez,nArg] = argn();
    select nArg
    case 0 then
        CountFunctionsFilesNames = [];//Имя файла по умолчанию пустое
        csvSeparator = ',';//.csv-разделитель по умолчанию запятая
        toIndexes = %t;//По умолчанию переводим в индексы
    case 1 then
        csvSeparator = ',';//.csv-разделитель по умолчанию запятая
        toIndexes = %t;//По умолчанию переводим в индексы
    case 2 then
        if type(csvSeparator) == 4 then
            toIndexes = csvSeparator;
            csvSeparator = ',';//.csv-разделитель по умолчанию запятая
        else
            toIndexes = %t;//По умолчанию переводим в индексы
        end
    end
    
    //Обрабатываем случай пустого файла
    if isempty(CountFunctionsFilesNames) then
        FunctionsNames = [];//Функций нет
        argumentsNames = [];//Имена (индексы) аргументов пустые
        rezultsNames = [];//Имена результатов пустые
        isVectorized = %t;//Функция векторизована
        
        //Выходим из функции
        return;
    end
    
    //Проверяем корректность аргументов
    CountFunctionsFilesNames = matrix(CountFunctionsFilesNames,1,-1);
    
    //Задаем условно десятичный разделитель
    if csvSeparator == '.' then
        csvDec = ',';
    else
        csvDec = '.';
    end
    
    //Считываем из файла имена и аттрибуты функций
    FunctionsAttributes = [];//Аттрибуты функций
    FunctionsNames = [];//Заголовки функций
    for CountFunctionsFileName=CountFunctionsFilesNames
        //Считываем заголовок функции и ее аттрибуты из файла
        [functionsAttributes,..//Аттрибуты функций
         functionsNames..//Имена функций
         ]=CSVFromFileToDatas(%t,CountFunctionsFileName,..
                              csvSeparator,csvDec,%f);

        //Добавляем несуществующие данные
        nFunctionsAttributes = NDatas(FunctionsAttributes);//Число исходных аттрибутов
        nFunctions = size(FunctionsNames,'*');
        nAddingFunctionsAttributes = NDatas(functionsAttributes);//Число добавляемых аттрибутов
        nAddingFunctions = size(functionsNames,'*');
        if nFunctionsAttributes < nAddingFunctionsAttributes then
            FunctionsAttributes = [FunctionsAttributes;..
                                   repmat('',[nAddingFunctionsAttributes - nFunctionsAttributes,nFunctions])];
        elseif nFunctionsAttributes > nAddingFunctionsAttributes then
            functionsAttributes = [functionsAttributes;..
                                   repmat('',[nFunctionsAttributes - nAddingFunctionsAttributes,nAddingFunctions])];
        end
        
        //Добавляем заголовок и аттрибуты в данные
        FunctionsNames = [FunctionsNames,functionsNames];
        FunctionsAttributes = [FunctionsAttributes,functionsAttributes];
    end
    [nAttributes,nFunctions] = NDatas(FunctionsAttributes);//Число аттрибутов и число функций
    
    //Парсим имена аргументов функций
    if nRez > 1 then
        if nAttributes > 0 then
            strCSVNames = SelectionDatasSubset(FunctionsAttributes,1);
            if or(length(strCSVNames) > 0) then
                argumentsNames = CellNamesFromStrCSV(strCSVNames,..
                                                     csvSeparator,..
                                                     toIndexes);
            else
                argumentsNames = [];//Имена (индексы) аргументов пустые
            end
        else
            argumentsNames = [];//Имена (индексы) аргументов пустые
        end
    end
    
    //Парсим имена значений функций
    if nRez > 2 then
        if nAttributes > 1 then
            strCSVNames = SelectionDatasSubset(FunctionsAttributes,2);
            if or(length(strCSVNames) > 0) then
                rezultsNames = CellNamesFromStrCSV(strCSVNames,..
                                                   csvSeparator,%f);
            else
                rezultsNames = [];
            end
        else
            rezultsNames = [];//Значения функции пустые
        end
    end
    
    //Парсим векторизацию
    if nRez > 3 then
        if nAttributes > 2 then
            isVectorized = SelectionDatasSubset(FunctionsAttributes,3);
            isVectorized = (isVectorized ~= '0');
        else
            if nAttributes == 0 then
                nFunctions = size(FunctionsNames,'*');
            end
            isVectorized = repmat(%t,[1,nFunctions]);
        end
    end
    
    //Формируем функции
    if nAttributes > 3 then
        FunctionsParametrs = SelectionDatasSubset(FunctionsAttributes,4);//Параметры функций
        Functions = ParametrsFunctionsStrsParse(FunctionsNames,..
                                                FunctionsParametrs);
    else
        Functions = ParametrsFunctionsStrsParse(FunctionsNames);
    end
endfunction
