//Расчет результатов
function [rezults,..//Результаты расчета
          rezultsHeaders..//Заголовки результатов
          ]=CountRezultsFile(isDataHeaders,..//Есть ли у входных данных заголовки?
                             inputDatasFileName,..//Имя файла входных данных
                             CountFunctionsFilesNames,..//Имя файла аттрибутов равномерно распределенных случайных величин
                             resultsDatasFileName,..//Имя файла результатов
                             csvSeparator,..//Разделитель .csv
                             csvDec..//Десятичный разделитель
                             )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('Function CountRezultsFile takes 2, 3, 4, 5 or 6 arguments');
    end
    switch nArg
    case 2 then
        CountFunctionsFilesNames = inputDatasFileName;
        inputDatasFileName = isDataHeaders;
        isDataHeaders = %t;//По умолчанию файл данных имеет заголовок
        resultsDatasFileName = [];//Имя файла результатов по умолчанию пустое
        csvSeparator = ',';//Разделитель .csv
        csvDec = '.';//Десятичный разделитель
    case 3 then
        if type(isDataHeaders) == 4 then
            resultsDatasFileName = [];//Имя файла результатов по умолчанию пустое
        else
            resultsDatasFileName = CountFunctionsFilesNames;
            CountFunctionsFilesNames = inputDatasFileName;
            inputDatasFileName = isDataHeaders;
            isDataHeaders = %t;//По умолчанию файл данных имеет заголовок
        end
        csvSeparator = ',';//Разделитель .csv
        csvDec = '.';//Десятичный разделитель
    case 4 then
        if type(isDataHeaders) == 4 then
            csvSeparator = ',';//Разделитель .csv
        else
            csvSeparator = resultsDatasFileName;
            resultsDatasFileName = CountFunctionsFilesNames;
            CountFunctionsFilesNames = inputDatasFileName;
            inputDatasFileName = isDataHeaders;
            isDataHeaders = %t;//По умолчанию файл данных имеет заголовок
        end
        csvDec = '.';//Десятичный разделитель
    case 5 then
        if type(isDataHeaders) == 4 then
            csvDec = '.';//Десятичный разделитель
        else
            csvDec = csvSeparator;
            csvSeparator = resultsDatasFileName;
            resultsDatasFileName = CountFunctionsFilesNames;
            CountFunctionsFilesNames = inputDatasFileName;
            inputDatasFileName = isDataHeaders;
            isDataHeaders = %t;//По умолчанию файл данных имеет заголовок
        end
    end
    
    //Проверяем корректность аргументов
    if (type(isDataHeaders) ~= 4) ||..
       (size(isDataHeaders, '*') > 1) then
       error('The argument isDataHeaders of function CountRezultsFile must be scalar boolean');
    end
    if (type(inputDatasFileName) ~= 10) ||..
       (size(inputDatasFileName,'*') ~= 1) then
        error('The argument inputDatasFileName of function CountRezultsFile must be scalar string');
    end
    if (type(CountFunctionsFilesNames) ~= 10) ||..
       (size(CountFunctionsFilesNames,'*') ~= 1) then
        error('The argument CountFunctionsFilesNames of function CountRezultsFile must be scalar string');
    end
    if (~isempty(resultsDatasFileName)) &&..
       ((type(resultsDatasFileName) ~= 10) ||..
        (size(resultsDatasFileName,'*') > 1)) then
        error('The argument resultsDatasFileName of function CountRezultsFile must be scalar string');
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') ~= 1) then
        error('The argument csvSeparator of function CountRezultsFile must be scalar string');
    end
    if (type(csvDec) ~= 10) ||..
       (size(csvDec,'*') ~= 1) then
        error('The argument csvDec of function CountRezultsFile must be scalar string');
    end
    
    //Считываем исходные данные из файла
    [inputDatas,..//Входные данные
     inputDatasHeaders..//Заголовки входных данных
     ]=CSVFromFileToDatas(isDataHeaders,inputDatasFileName,..
                          csvSeparator,csvDec,%t);
    
    //Выполняем расчет с последующим сохранением в файл
    [rezults,..//Результаты расчета
     rezultsHeaders..//Заголовки результатов
     ]=CountRezultsSave(inputDatas,inputDatasHeaders,CountFunctionsFilesNames,resultsDatasFileName,..
                        csvSeparator,csvDec);
endfunction
