//Расчет результатов
function [rezults,..//Результаты расчета
          rezultsHeaders..//Заголовки результатов
          ]=CountRezultsSave(inputDatas,..//Входные данные
                             inputDatasHeaders,..//Заголовки входных данных
                             CountFunctionsFilesNames,..//Имя файла аттрибутов равномерно распределенных случайных величин
                             resultsDatasFileName,..//Имя файла результатов
                             csvSeparator,..//Разделитель .csv
                             csvDec..//Десятичный разделитель
                             )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('Function CountRezultsSave takes 2, 3, 4, 5 or 6 arguments');
    end
    switch nArg
    case 2 then
        CountFunctionsFilesNames = inputDatasHeaders;
        inputDatasHeaders = [];//Заголовки входных данных по умолчанию берем пустым
        resultsDatasFileName = [];//Имя файла результатов
        csvSeparator = ',';//Разделитель .csv
        csvDec = '.';//Десятичный разделитель
    case 3 then
        resultsDatasFileName = [];//Имя файла результатов
        csvSeparator = ',';//Разделитель .csv
        csvDec = '.';//Десятичный разделитель
    case 4 then
        csvSeparator = ',';//Разделитель .csv
        csvDec = '.';//Десятичный разделитель
    case 5 then
        csvDec = '.';//Десятичный разделитель
    end
    
    //Проверяем корректность аргументов
    if ~IsTableDatas(inputDatas) then
        error('The argument inputDatas of function CountRezultsSave must be matrix of real');
    end
    if (~isempty(inputDatasHeaders)) && (type(inputDatasHeaders) ~= 10) then
        error('The inputDatasHeaders argument of function CountRezults must be matrix 1xM of string');
    end
    if (~IsTableDatasAndHeaders(inputDatas,inputDatasHeaders)) then
        error('The numbers of columns of arguments inputDatasHeaders and inputDatas of functions CountRezults must be equality');
    end
    if (type(CountFunctionsFilesNames) ~= 10) then
        error('The argument CountFunctionsFilesNames of function CountRezultsSave must be matrix of string');
    end
    if (~isempty(resultsDatasFileName)) &&..
       ((type(resultsDatasFileName) ~= 10) ||..
        (size(resultsDatasFileName,'*') > 1)) then
        error('The argument resultsDatasFileName of function CountRezultsSave must be scalar string');
    end
    if (type(csvSeparator) ~= 10) ||..
       (size(csvSeparator,'*') ~= 1) then
        error('The argument csvSeparator of function CountRezultsSave must be scalar string');
    end
    if (type(csvDec) ~= 10) ||..
       (size(csvDec,'*') ~= 1) then
        error('The argument csvDec of function CountRezultsSave must be scalar string');
    end
    
    //Парсим файлы функций
    [Functions,..//Функции
     argumentsNames,..//Имена (индексы) аргументов
     rezultsNames,..//Имена результатов
     isVectorized..//Функция векторизована или нет
     ]=CountFunctionsParse(CountFunctionsFilesNames,..
                           csvSeparator,..
                           isempty(inputDatasHeaders));
    
    //Выполняем функцию
    [rezults,..//Результаты расчета
     rezultsHeaders..//Заголовки результатов
     ]=CountRezults(inputDatas,inputDatasHeaders,Functions,..
                    argumentsNames,rezultsNames,isVectorized);
    
    //Сохраняем результаты расчетов в файл
    if ~isempty(resultsDatasFileName) then
        DatasToCSVFile(rezults,rezultsHeaders,%t,..
                       resultsDatasFileName,..
                       csvSeparator,csvDec);
    end
endfunction
