//Генерация случайных чисел на поддиапазонах с равномерным законом распределения
function [randomValues,..//Случайные величины
          randomValuesMin,..//Минимальные значения случайных величин
          randomValuesMax..//Максимальные значения случайных величин
          ]=RandomGenerateUniformOnRanges(randomValuesHeaders,..//Заголовки случайных величин
                                          randomValuesMin,..//Минимальные значения случайных величин
                                          randomValuesMax,..//Максимальные значения случайных величин
                                          nValues,..//Число сгенерированных совокупностей случайных величин
                                          typeGenetate,..//Тип генерации
                                          PredicateFunction,..//Функция предиката
                                          PredicateFunctionArgumentHeaders,..//Заголовки аргументов функции предиката
                                          isPredicateVectorized..//Векторизован ли предикат
                                          )
    //Проверяем агрументы
    nArg = argn(2);//Числа аргументов
    if nArg < 2 then
        error('The function RandomGenerateUniformOnRanges takes 2 - 8 arguments');
    end
    select nArg
    case 2 then
        randomValuesMax = randomValuesMin;
        randomValuesMin = randomValuesHeaders;
        randomValuesHeaders = [];
        nValues = 1;//По умолчанию генерируем одну совокупность случайных величин
        typeGenetate = 0;//Тип генерации по умолчанию ноль
        PredicateFunction = [];//Функция предиката по умолчанию пустая
        PredicateFunctionArgumentHeaders = [];//Заголовки аргументов функции предиката по умолчанию пустые
        isPredicateVectorized = %t;//По умолчанию предикат векторизован
    case 3 then
        if isempty(randomValuesHeaders) ||..
           (type(randomValuesHeaders) == 10) then
            nValues = 1;//По умолчанию генерируем одну совокупность случайных величин
        else
            nValues = randomValuesMax;
            randomValuesMax = randomValuesMin;
            randomValuesMin = randomValuesHeaders;
            randomValuesHeaders = [];
        end
        typeGenetate = 0;//Тип генерации по умолчанию ноль
        PredicateFunction = [];//Функция предиката по умолчанию пустая
        PredicateFunctionArgumentHeaders = [];//Заголовки аргументов функции предиката по умолчанию пустые
        isPredicateVectorized = %t;//По умолчанию предикат векторизован
    case 4 then
        if isempty(randomValuesHeaders) ||..
           (type(randomValuesHeaders) == 10) then
            typeGenetate = 0;//Тип генерации по умолчанию ноль
        else
            typeGenetate = nValues;
            nValues = randomValuesMax;
            randomValuesMax = randomValuesMin;
            randomValuesMin = randomValuesHeaders;
            randomValuesHeaders = [];
        end
        PredicateFunction = [];//Функция предиката по умолчанию пустая
        PredicateFunctionArgumentHeaders = [];//Заголовки аргументов функции предиката по умолчанию пустые
        isPredicateVectorized = %t;//По умолчанию предикат векторизован
    case 5 then
        if isempty(randomValuesHeaders) ||..
           (type(randomValuesHeaders) == 10) then
            if IsCountFunction(typeGenetate) then
                PredicateFunction = typeGenetate;
                typeGenetate = 0;//Тип генерации по умолчанию ноль
            else
                PredicateFunction = [];//Функция предиката по умолчанию пустая
            end
        else
            PredicateFunction = typeGenetate;
            typeGenetate = nValues;
            nValues = randomValuesMax;
            randomValuesMax = randomValuesMin;
            randomValuesMin = randomValuesHeaders;
            randomValuesHeaders = [];
        end
        PredicateFunctionArgumentHeaders = [];//Заголовки аргументов функции предиката по умолчанию пустые
        isPredicateVectorized = %t;//По умолчанию предикат векторизован
    case 6 then
        if isempty(randomValuesHeaders) ||..
           (type(randomValuesHeaders) == 10) then
            if IsCountFunction(typeGenetate) then
                PredicateFunctionArgumentHeaders = PredicateFunction;
                PredicateFunction = typeGenetate;
                typeGenetate = 0;//Тип генерации по умолчанию ноль
            else
                PredicateFunctionArgumentHeaders = [];//Заголовки аргументов функции предиката по умолчанию пустые
            end
        else
            PredicateFunctionArgumentHeaders = PredicateFunction;
            PredicateFunction = typeGenetate;
            typeGenetate = nValues;
            nValues = randomValuesMax;
            randomValuesMax = randomValuesMin;
            randomValuesMin = randomValuesHeaders;
            randomValuesHeaders = [];
        end
        isPredicateVectorized = %t;//По умолчанию предикат векторизован
    case 7 then
        if isempty(randomValuesHeaders) ||..
           (type(randomValuesHeaders) == 10) then
            if IsCountFunction(typeGenetate) then
                PredicateFunctionArgumentHeaders = PredicateFunction;
                PredicateFunction = typeGenetate;
                typeGenetate = 0;//Тип генерации по умолчанию ноль
            else
                PredicateFunctionArgumentHeaders = [];//Заголовки аргументов функции предиката по умолчанию пустые
            end
            isPredicateVectorized = %t;//По умолчанию предикат векторизован
        else
            isPredicateVectorized = PredicateFunctionArgumentHeaders;
            PredicateFunctionArgumentHeaders = PredicateFunction;
            PredicateFunction = typeGenetate;
            typeGenetate = nValues;
            nValues = randomValuesMax;
            randomValuesMax = randomValuesMin;
            randomValuesMin = randomValuesHeaders;
            randomValuesHeaders = [];
        end
    end
    
    //Проверяем корректность аргументов
    if (~isempty(randomValuesHeaders)) &&..
       (type(randomValuesHeaders) ~= 10) then
        error('The argument randomValuesHeaders of function RandomGenerateUniformOnRanges must be matrix of string 1xM');
    end
    if isempty(randomValuesMin) ||..
       (type(randomValuesMin) ~= 1) ||..
       (NDatas(randomValuesMin) > 1) then
        error('The argument randomValuesMin of function RandomGenerateUniformOnRanges must be matrix of real 1xM');
    end
    if isempty(randomValuesMax) ||..
       (type(randomValuesMax) ~= 1) ||..
       (NDatas(randomValuesMax) > 1) then
        error('The argument randomValuesMax of function RandomGenerateUniformOnRanges must be matrix of real 1xM');
    end
    if ~IsTableDatasAndHeaders(randomValuesMin,randomValuesHeaders) then
        error('The number of columns of arguments randomValuesMin and randomValuesHeaders must be equality and randomValuesHeaders must be table datas'' headers');
    end
    if ~IsTableDatasAndHeaders(randomValuesMax,randomValuesHeaders) then
        error('The number of columns of arguments randomValuesMax and randomValuesHeaders must be equality and randomValuesHeaders must be table datas'' headers');
    end
    if (type(nValues) ~= 1) && (size(nValues,'*') ~= 1) then
        error('The argument nValues of function RandomGenerateUniformOnRanges must be integer scalar');
    end
    if (type(typeGenetate) ~= 1) &&..
       ((size(typeGenetate,'*') ~= 1) || (~or(typeGenetate == [0:7]))) then
        error('The argument typeGenetate of function RandomGenerateUniformOnRanges must be integer scalar in range 0.' + '.' + '.7');
    end
    if (~isempty(PredicateFunction)) && (type(PredicateFunction) ~= 13) then
        error('The argument PredicateFunction of function RandomGenerateUniformOnRanges must be function');
    end
    if (~isempty(PredicateFunctionArgumentHeaders)) &&..
       ((type(PredicateFunctionArgumentHeaders) ~= 10) &&..
        (type(PredicateFunctionArgumentHeaders) ~= 1) ||..
        (size(PredicateFunctionArgumentHeaders)(1) ~= 1)) then
        error('The argument PredicateFunctionArgumentHeaders of function RandomGenerateUniformOnRanges must be matrix of string or integer indexes 1xM');
    end
    if isempty(isPredicateVectorized) ||..
       (type(isPredicateVectorized) ~= 4) then
        error('The argument isPredicateVectorized of RandomGenerateUniformOnRanges must be scalar boolean');
    end
    
    //Получаем при необходимости верхнюю и нижнюю границы диапазона
    select modulo(typeGenetate,4)
    case 0 then
        if or(randomValuesMax < randomValuesMin) then
            error('The randomValuesMax argument of function RandomGenerateUniformOnRanges must be more argument randomValuesMin of this function');
        end
    case 1 then
        //Получаем максимум и минимум
        indPlus = randomValuesMax > 0;
        randomValuesMax(indPlus) = randomValuesMin(indPlus) + randomValuesMax(indPlus);
        _randomValuesMax = randomValuesMin(~indPlus);
        randomValuesMin(~indPlus) = randomValuesMin(~indPlus) + randomValuesMax(~indPlus);
        randomValuesMax(~indPlus) = _randomValuesMax;
        
        //Чистим память
        clear _randomValuesMax;
        clear indPlus;
    case 2 then
        //Получаем максимум и минимум
        _randomValuesMax = randomValuesMax;
        randomValuesMax = randomValuesMin + abs(_randomValuesMax);
        randomValuesMin = randomValuesMin - abs(_randomValuesMax);
        
        //Чистим памәтғ
        clear _randomValuesMax;
    case 3 then
        //Получаем максимум и минимум
        _randomValuesMax = randomValuesMax;
        randomValuesMax = randomValuesMin + abs(_randomValuesMax) / 2;
        randomValuesMin = randomValuesMin - abs(_randomValuesMax) / 2;
        
        //Чистим памәтғ
        clear _randomValuesMax;
    end
    if typeGenetate > 3 then
        randomValuesMin = ceil(randomValuesMin);
        randomValuesMax = floor(randomValuesMax);
        if or(randomValuesMax < randomValuesMin) then
            randomValues = [];
            return;
        end
    end
    
    //Генерируем (итерационно) случайные значения в диапазоне
    nRandomValues = 0;
    _nValues = nValues;
    while nRandomValues < nValues
        //Генерируем случайные значения в диапазоне
        nHeadersDatas = size(randomValuesMin,'*');//Число заголовков данных
        randomValues = rand(_nValues,nHeadersDatas);
        randomValues = repmat(randomValuesMin,[_nValues,1]) + repmat(randomValuesMax - randomValuesMin,[_nValues,1]) .* randomValues;
        if typeGenetate > 3 then
            randomValues = round(randomValues);
        end
        
        //Обрабатываем сгенерированные случајные величины
        if ~isempty(PredicateFunction) then
            //Отсеиваем случайные значения, не удовлетворяющие предикату
            checked = CountFunction(randomValues,randomValuesHeaders,..
                                    PredicateFunction,..
                                    PredicateFunctionArgumentHeaders,..
                                    isPredicateVectorized);
            randomValues = SelectionDatasSubset(randomValues,checked);//Отсеиваем данные, не удовлетворяющие условию
            
            //Получаем число случайных данных
            nRandomValues = NDatas(randomValues);//Число оставшихсә сгенерированных величин
            if nRandomValues > nValues then
                randomValues = SelectionDatasSubset(randomValues,1:nValues);//Отсеиваем лишние данные
                return;
            end
            
            //Обновляем число величин
            _nValues = _nValues ^ 2;
            if nRandomValues > 0 then
                _nValues = cell(_nValues / nRandomValues);
            end
        else
            return;
        end
    end
endfunction
